<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Web.Syndication

Windows Runtime (WinRT) APIs for for the `Windows.Web.Syndication` namespace.

This package provides the `winrt.windows.web.syndication` module.
